#!/usr/bin/python


"""Evaluation tool described in:

    Javad Nouri and Roman Yangarber. "A Novel Evaluation Method for
    Morpholog- ical Segmentation". In: Proceedings of LREC 2016: the
    Tenth International Conference on Language Resources and
    Evaluation. Portoroz, Slovenia, 2016. isbn: 978-2-9517408-9-1.

    (Code) Author: Javad Nouri 
    first.last  <at> cs.helsinki.fi

"""


#Check if utabulate package is installed
try:
    #from tabulate import tabulate
    from optparse import OptionParser
    import sys
    from morpho import io, evaluation
except ImportError, ex:
    print >>sys.stderr, "Package does not exist. Please install the requrired package using pip or similar tools:", ex
    sys.exit(1)






if __name__ == '__main__':
    parser = OptionParser(usage='%prog [options] segmentation_files')
    parser.add_option('-g', '--gold-file', dest='gold_file', help='path to gold standard file.', metavar='FILE')
    parser.add_option('-l', '--label-file', dest='label_file', help='path to label definition file.', metavar='FILE')

    parser.add_option('-v', '--verbose', action='store_true', dest='verbose', default=False, help='print extra information.')
    
    (options, args) = parser.parse_args()
    
    if len(args) == 0:
        print >> sys.stderr, '\nPlease provide a segmentation file name to be evaluated.'
        parser.print_help()
        sys.exit(2)
    if options.gold_file is None or options.label_file is None:
        print >> sys.stderr, '\nPlease provide gold standard and label definition file names.'
        parser.print_help()
        sys.exit(2)
        
    seg_file = args[0]
    gold_file  = options.gold_file
    label_file = options.label_file
    io.verbose = options.verbose


    gold, labels = evaluation.read_and_validate_gold(gold_file, label_file)
    print
    for seg_file in args:        
        segs = io.read_simple_segmentation_file(seg_file)

        stats, results = evaluation.evaluate(gold, labels, segs, False)
        print '*************************************************'
        print seg_file
        print io.utabulate([stats], headers=['#gold bounaries', '#response boundaries', '#intersect(gold, response)', '#matches', '#possible boundaries'])
        print
        print io.utabulate([results], headers=['precision', 'recall', 'f1', 'acuuracy'])
        print
    

